@@ -14,21 +14,26 @@ NULL
 #'
 #' @param x [problem()] (i.e. [`ConservationProblem-class`]) object.
 #'
-#' @param weights `numeric` or `matrix` of weights. See the
-#'   Details section for more information.
+#' @param weights `numeric` or `matrix` of weights.
+#'   See the Weights format section for more information.
 #'
-#' @details Weights can only be applied to problems that have an objective
-#'   that is budget limited (e.g. [add_max_cover_objective()]). #'
-#'   They can be applied to problems that aim to maximize phylogenetic
-#'   representation ([add_max_phylo_div_objective()]) to favor the
-#'   representation of specific features over the representation of
-#'   some phylogenetic branches. Weights cannot be negative values
-#'   and must have values that are equal to or larger than zero.
-#'   **Note that planning unit costs are scaled to 0.01 to identify
-#'   the cheapest solution among multiple optimal solutions. This means
-#'   that the optimization process will favor cheaper solutions over solutions
-#'   that meet feature targets (or occurrences) when feature weights are
-#'   lower than 0.01.**
+#' @details
+#' Weights can only be applied to problems that have an objective
+#' that is budget limited (e.g. [add_max_cover_objective()]).
+#' They can be applied to problems that aim to maximize phylogenetic
+#' representation ([add_max_phylo_div_objective()]) to favor the
+#' representation of specific features over the representation of
+#' some phylogenetic branches. Weights cannot be negative values
+#' and must have values that are equal to or larger than zero.
+#' **Note that planning unit costs are scaled to 0.01 to identify
+#' the cheapest solution among multiple optimal solutions. This means
+#' that the optimization process will favor cheaper solutions over solutions
+#' that meet feature targets (or occurrences) when feature weights are
+#' lower than 0.01.**
+#'
+#' @section Weights format:
+#'
+#' The argument to `weights` can be specified using the following formats.
 #'
 #'   \describe{
 #'
@@ -63,11 +68,12 @@ NULL
 #'
 #' # create minimal problem that aims to maximize the number of features
 #' # adequately conserved given a total budget of 3800. Here, each feature
-#' # needs 20 % of its habitat for it to be considered adequately conserved
+#' # needs 20% of its habitat for it to be considered adequately conserved
 #' p1 <- problem(sim_pu_raster, sim_features) %>%
 #'       add_max_features_objective(budget = 3800) %>%
 #'       add_relative_targets(0.2) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #'
 #' # create weights that assign higher importance to features with less
 #' # suitable habitat in the study area
@@ -97,12 +103,13 @@ NULL
 #' plot(sim_phylogeny, main = "simulated phylogeny")
 #' }
 #' # create problem with a maximum phylogenetic diversity objective,
-#' # where each feature needs 10 % of its distribution to be secured for
+#' # where each feature needs 10% of its distribution to be secured for
 #' # it to be adequately conserved and a total budget of 1900
 #' p4 <- problem(sim_pu_raster, sim_features) %>%
 #'       add_max_phylo_div_objective(1900, sim_phylogeny) %>%
 #'       add_relative_targets(0.1) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #' \dontrun{
 #' # solve problem
 #' s4 <- solve(p4)
@@ -110,14 +117,14 @@ NULL
 #' # plot solution
 #' plot(s4, main = "solution", axes = FALSE, box = FALSE)
 #'
-#' # find which features have their targets met
-#' targets_met4 <- cellStats(s4 * sim_features, "sum") >
-#'                 (0.1 * cellStats(sim_features, "sum"))
+#' # find out which features have their targets met
+#' r4 <- eval_target_coverage_summary(p4, s4)
+#' print(r4, width = Inf)
 #'
 #' # plot the example phylogeny and color the represented features in red
 #' plot(sim_phylogeny, main = "represented features",
 #'      tip.color = replace(rep("black", nlayers(sim_features)),
-#'                          which(targets_met4), "red"))
+#'                          which(r4$met), "red"))
 #' }
 #' # we can see here that the third feature ("layer.3", i.e.
 #' # sim_features[[3]]) is not represented in the solution. Let us pretend
@@ -142,8 +149,8 @@ NULL
 #' plot(s5, main = "solution", axes = FALSE, box = FALSE)
 #'
 #' # find which features have their targets met
-#' targets_met5 <- cellStats(s5 * sim_features, "sum") >
-#'                 (0.1 * cellStats(sim_features, "sum"))
+#' r5 <- eval_target_coverage_summary(p4, s5)
+#' print(r5, width = Inf)
 #'
 #' # plot the example phylogeny and color the represented features in red
 #' # here we can see that this solution only adequately conserves the
@@ -152,16 +159,17 @@ NULL
 #' # diverse set of three different features.
 #' plot(sim_phylogeny, main = "represented features",
 #'      tip.color = replace(rep("black", nlayers(sim_features)),
-#'                          which(targets_met5), "red"))
+#'                          which(r5$met), "red"))
 #' }
 #' # create multi-zone problem with maximum features objective,
-#' # with 10 % representation targets for each feature, and set
+#' # with 10% representation targets for each feature, and set
 #' # a budget such that the total maximum expenditure in all zones
 #' # cannot exceed 3000
 #' p6 <- problem(sim_pu_zones_stack, sim_features_zones) %>%
 #'       add_max_features_objective(3000) %>%
 #'       add_relative_targets(matrix(0.1, ncol = 3, nrow = 5)) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #'
 #' # create weights that assign equal weighting for the representation
 #' # of each feature in each zone except that it does not matter if
@@ -185,12 +193,13 @@ NULL
 #' # create minimal problem to show the correct method for setting
 #' # weights for problems with manual targets
 #' p8 <- problem(sim_pu_raster, sim_features) %>%
-#'       add_max_features_objective(budget = 1500) %>%
+#'       add_max_features_objective(budget = 3000) %>%
 #'       add_manual_targets(data.frame(feature = c("layer.1", "layer.4"),
 #'                                     type = "relative",
 #'                                     target = 0.1)) %>%
 #'       add_feature_weights(matrix(c(1, 200), ncol = 1)) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #' \dontrun{
 #' # solve problem
 #' s8 <- solve(p8)
@@ -253,15 +262,13 @@ methods::setMethod("add_feature_weights",
       weights <- as.data.frame(weights)
       colnames(weights) <- x$zone_names()
       rownames(weights) <- x$feature_names()
-      rfun <- function(x)
-        utils::getFromNamespace("rHandsontableOutput", "rhandsontable")(x)
       nc <- ncol(weights)
       nr <- nrow(weights)
       vfun <- function(x)
         assertthat::see_if(ncol(x) == nc, nrow(x) == nr,
                            all(is.finite(as.matrix(x))),
                            all(as.matrix(x) >= 0))
-      p <- misc_parameter("weights", weights, vfun, rfun)
+      p <- misc_parameter("weights", weights, vfun)
     }
     # add weights to problem
     x$add_penalty(pproto(
