@@ -102,7 +102,7 @@ NULL
 #'   may not be an optimal solution depending on the gap used to solve
 #'   the problem and noting that the default gap is 0.1).
 #'
-#' @seealso [feature_representation()], [problem()],
+#' @seealso [eval_feature_representation_summary()], [problem()],
 #'   [solvers], [category_layer()],
 #'   [presolve_check()].
 #'
@@ -118,7 +118,8 @@ NULL
 #' p1 <- problem(sim_pu_raster, sim_features) %>%
 #'       add_min_set_objective() %>%
 #'       add_relative_targets(0.1) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #' \dontrun{
 #' # solve the problem
 #' s1 <- solve(p1)
@@ -132,7 +133,7 @@ NULL
 #' print(attr(s1, "status"))
 #'
 #' # calculate feature representation in the solution
-#' r1 <- feature_representation(p1, s1)
+#' r1 <- eval_feature_representation_summary(p1, s1)
 #' print(r1)
 #'
 #' # plot solution
@@ -142,7 +143,8 @@ NULL
 #' p2 <- problem(sim_pu_polygons, sim_features, cost_column = "cost") %>%
 #'       add_min_set_objective() %>%
 #'       add_relative_targets(0.1) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #' \dontrun{
 #' # solve the problem
 #' s2 <- solve(p2)
@@ -151,7 +153,7 @@ NULL
 #' print(head(s2))
 #'
 #' # calculate feature representation in the solution
-#' r2 <- feature_representation(p2, s2[, "solution_1"])
+#' r2 <- eval_feature_representation_summary(p2, s2[, "solution_1"])
 #' print(r2)
 #'
 #' # plot solution
@@ -162,7 +164,8 @@ NULL
 #' p3 <- problem(sim_pu_sf, sim_features, cost_column = "cost") %>%
 #'       add_min_set_objective() %>%
 #'       add_relative_targets(0.1) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #' \dontrun{
 #' # solve the problem
 #' s3 <- solve(p3)
@@ -171,7 +174,7 @@ NULL
 #' print(head(s3))
 #'
 #' # calculate feature representation in the solution
-#' r3 <- feature_representation(p3, s3[, "solution_1"])
+#' r3 <- eval_feature_representation_summary(p3, s3[, "solution_1"])
 #' print(r3)
 #'
 #' # plot solution
@@ -183,7 +186,8 @@ NULL
 #'       add_min_set_objective() %>%
 #'       add_relative_targets(matrix(runif(15, 0.1, 0.2), nrow = 5,
 #'                                   ncol = 3)) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #' \dontrun{
 #' # solve the problem
 #' s4 <- solve(p4)
@@ -192,7 +196,7 @@ NULL
 #' print(s4)
 #'
 #' # calculate feature representation in the solution
-#' r4 <- feature_representation(p4, s4)
+#' r4 <- eval_feature_representation_summary(p4, s4)
 #' print(r4)
 #'
 #' # plot solution
@@ -204,7 +208,8 @@ NULL
 #'       add_min_set_objective() %>%
 #'       add_relative_targets(matrix(runif(15, 0.1, 0.2), nrow = 5,
 #'                                   ncol = 3)) %>%
-#'       add_binary_decisions()
+#'       add_binary_decisions() %>%
+#'       add_default_solver(verbose = FALSE)
 #' \dontrun{
 #' # solve the problem
 #' s5 <- solve(p5)
@@ -213,9 +218,8 @@ NULL
 #' print(head(s5))
 #'
 #' # calculate feature representation in the solution
-#' r5 <- feature_representation(p5, s5[, c("solution_1_zone_1",
-#'                                         "solution_1_zone_2",
-#'                                         "solution_1_zone_3")])
+#' r5 <- eval_feature_representation_summary(
+#'   p5, s5[, c("solution_1_zone_1", "solution_1_zone_2", "solution_1_zone_3")])
 #' print(r5)
 #'
 #' # create new column representing the zone id that each planning unit
@@ -312,6 +316,7 @@ methods::setMethod(
         } else {
           ret <- ret[[1]]
         }
+        names(ret) <- a$zone_names()
         return(ret)
       })
       names(ret) <- paste0("solution_", seq_along(sol))
@@ -372,13 +377,15 @@ methods::setMethod(
     if (length(ret) == 1 && default_portfolio)
       ret <- ret[[1]]
     # add attributes
-    attr(ret, "objective") <- stats::setNames(vapply(sol, `[[`, numeric(1), 2),
-                                              paste0("solution_",
-                                                     seq_along(sol)))
-    attr(ret, "status") <- stats::setNames(vapply(sol, `[[`, character(1), 3),
-                                           paste0("solution_", seq_along(sol)))
-    attr(ret, "runtime") <- stats::setNames(vapply(sol, `[[`, numeric(1), 4),
-                                            paste0("solution_", seq_along(sol)))
+    attr(ret, "objective") <-
+      stats::setNames(
+        vapply(sol, `[[`, numeric(1), 2), paste0("solution_", seq_along(sol)))
+    attr(ret, "status") <-
+      stats::setNames(
+        vapply(sol, `[[`, character(1), 3), paste0("solution_", seq_along(sol)))
+    attr(ret, "runtime") <-
+      stats::setNames(
+        vapply(sol, `[[`, numeric(1), 4), paste0("solution_", seq_along(sol)))
     # return object
     return(ret)
   }
