@@ -26,16 +26,15 @@ test_that("compile (compressed formulation, single zone)", {
   expect_equal(o$A()[n_features + 1, ],
     c(p$planning_unit_costs(), rep(0, n_features)))
   expect_true(all(o$A()[seq_len(n_features), n_pu + seq_len(n_features)] ==
-    Matrix::sparseMatrix(i = seq_len(n_features), j = seq_len(n_features),
-      x = (-1 * targ), giveCsparse = FALSE)))
+    triplet_sparse_matrix(
+      i = seq_len(n_features), j = seq_len(n_features), x = (-1 * targ))))
   expect_true(all(o$lb() == 0))
   expect_true(all(o$ub() == 1))
 })
 
 test_that("solution (compressed formulation, single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # create data
   budget <- 4.23
   cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
@@ -108,8 +107,7 @@ test_that("compile (expanded formulation, single zone)", {
 
 test_that("solution (expanded formulation, single zone)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # create data
   budget <- 4.23
   cost <- raster::raster(matrix(c(1, 2, 2, NA), ncol = 4))
@@ -131,6 +129,7 @@ test_that("solution (expanded formulation, single zone)", {
 })
 
 test_that("invalid inputs (single zone)", {
+  data(sim_pu_raster, sim_features)
   # check that invalid arguments result in errors
   expect_error({
     problem(sim_pu_raster, sim_features) %>%
@@ -152,6 +151,12 @@ test_that("invalid inputs (single zone)", {
       add_max_features_objective(budget = Inf) %>%
       add_absolute_targets(targ)
   })
+  # check that no targets results in error
+  expect_error({
+    problem(sim_pu_raster, sim_pu_raster) %>%
+    add_max_features_objective(budget = 5) %>%
+    compile()
+  })
 })
 
 test_that("compile (compressed formulation, multiple zones, scalar budget)", {
@@ -211,8 +216,7 @@ test_that("compile (compressed formulation, multiple zones, scalar budget)", {
 
 test_that("solve (compressed formulation, multiple zones, scalar budget)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make and solve problem
   budget <- 7
   locked_out <- matrix(FALSE, ncol = 2, nrow = 5)
@@ -325,8 +329,7 @@ test_that("compile (expanded formulation, multiple zones, scalar budget)", {
 
 test_that("solve (expanded formulation, multiple zones, scalar budget)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make and solve problem
   budget <- 7
   locked_out <- matrix(FALSE, ncol = 2, nrow = 5)
@@ -421,8 +424,7 @@ test_that("compile (compressed formulation, multiple zones, vector budget)", {
 
 test_that("solve (compressed formulation, multiple zones, vector budget)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make and solve problem
   budget <- c(6, 1)
   locked_out <- matrix(FALSE, ncol = 2, nrow = 5)
@@ -539,8 +541,7 @@ test_that("compile (expanded formulation, multiple zones, vector budget)", {
 
 test_that("solve (expanded formulation, multiple zones, vector budget)", {
   skip_on_cran()
-  skip_on_ci()
-  skip_if_not(any_solvers_installed())
+  skip_if_no_fast_solvers_installed()
   # make and solve problem
   budget <- c(6, 1)
   locked_out <- matrix(FALSE, ncol = 2, nrow = 5)
@@ -574,8 +575,9 @@ test_that("solve (expanded formulation, multiple zones, vector budget)", {
   expect_equal(raster::values(s[[2]]), c(0, 0, 0, 1, NA))
 })
 
-test_that("invalid inptus (multiple zones)", {
+test_that("invalid inputs (multiple zones)", {
   data(sim_pu_zones_stack, sim_features_zones)
+  # check that invalid arguments result in errors
   expect_error({
     problem(sim_pu_zones_stack, sim_features_zones) %>%
     add_max_features_objective(budget = c(1, -5, 1))
@@ -596,4 +598,10 @@ test_that("invalid inptus (multiple zones)", {
     problem(sim_pu_zones_stack, sim_features_zones) %>%
     add_max_features_objective(budget = c(1, Inf, 9))
   })
+  # check that no targets results in error
+  expect_error({
+    problem(sim_pu_zones_stack, sim_features_zones) %>%
+    add_max_features_objective(budget = c(5, 5, 5)) %>%
+    compile()
+  })
 })
