@@ -42,7 +42,7 @@ test_that("x=Raster, features=RasterStack", {
                     list(rij_matrix(sim_pu_raster, sim_features)))
   expect_equal(names(x$data$rij_matrix), x$zone_names())
   expect_equal(rownames(x$data$rij_matrix[[1]]), x$feature_names())
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -99,7 +99,7 @@ test_that("x=RasterStack, features=ZonesRaster", {
                matrix(feature_names(sim_features_zones),
                       ncol = number_of_zones(sim_features_zones),
                       nrow = number_of_features(sim_features_zones)))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -149,7 +149,7 @@ test_that("x=SpatialPolygonsDataFrame, features=RasterStack", {
                       !is.na(sim_pu_polygons[[1]]), ], sim_features)))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), names(sim_features))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -207,7 +207,7 @@ test_that("x=SpatialPolygonsDataFrame, features=ZonesRaster", {
                matrix(feature_names(sim_features_zones),
                       ncol = number_of_zones(sim_features_zones),
                       nrow = number_of_features(sim_features_zones)))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -255,7 +255,7 @@ test_that("x=SpatialLinesDataFrame, features=RasterStack", {
                       !is.na(sim_pu_lines[[1]]), ], sim_features)))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), names(sim_features))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -303,7 +303,7 @@ test_that("x=SpatialPointsDataFrame, features=RasterStack", {
                       !is.na(sim_pu_points[[1]]), ], sim_features)))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), names(sim_features))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -356,7 +356,7 @@ test_that("x=SpatialPolygonsDataFrame, features=character", {
   expect_true(all(x$data$rij_matrix[[1]] == rij[[1]]))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]),  c("spp1", "spp2"))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -438,7 +438,7 @@ test_that("x=SpatialPolygonsDataFrame, features=ZonesCharacter", {
   expect_equal(names(x$data$rij_matrix), c("z1", "z2"))
   expect_true(all(x$data$rij_matrix[[1]] == rij[[1]]))
   expect_true(all(x$data$rij_matrix[[2]] == rij[[2]]))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -486,7 +486,7 @@ test_that("x=data.frame, features=character", {
                                        dims = c(2, 9))))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), c("spp1", "spp2"))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -548,7 +548,7 @@ test_that("x=data.frame, features=ZonesCharacter", {
   expect_equal(names(x$data$rij_matrix), c("1", "2"))
   expect_equal(rownames(x$data$rij_matrix[[1]]), c("1", "2"))
   expect_equal(rownames(x$data$rij_matrix[[2]]), c("1", "2"))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -598,7 +598,7 @@ test_that("x=data.frame, features=data.frame (single zone)", {
                                          dims = c(5, 9)))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), letters[1:5])
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -659,7 +659,7 @@ test_that("x=data.frame, features=data.frame (multiple zones)", {
                                          dims = c(5, 9)))
   expect_equal(rownames(x$data$rij_matrix[[1]]), letters[1:5])
   expect_equal(rownames(x$data$rij_matrix[[2]]), letters[1:5])
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -702,7 +702,7 @@ test_that("x=numeric, features=data.frame", {
   expect_equivalent(x$data$rij_matrix[[1]],
                     as(t(pu[-2, 3:4]), "sparseMatrix"))
   expect_equal(rownames(x$data$rij_matrix[[1]]), c("spp1", "spp2"))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -756,7 +756,7 @@ test_that("x=matrix, features=data.frame", {
                     as(t(pu[-2, 6:7]), "sparseMatrix"))
   expect_equal(rownames(x$data$rij_matrix[[1]]), c("spp1", "spp2"))
   expect_equal(rownames(x$data$rij_matrix[[2]]), c("spp1", "spp2"))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -806,7 +806,7 @@ test_that("x=sf, features=RasterStack", {
                       !is.na(sim_pu_polygons[[1]]), ], sim_features)))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), names(sim_features))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -865,7 +865,7 @@ test_that("x=sf, features=ZonesRaster", {
                matrix(feature_names(sim_features_zones),
                       ncol = number_of_zones(sim_features_zones),
                       nrow = number_of_features(sim_features_zones)))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -918,7 +918,7 @@ test_that("x=sf, features=character", {
   expect_true(all(x$data$rij_matrix[[1]] == rij[[1]]))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]),  c("spp1", "spp2"))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -1000,7 +1000,7 @@ test_that("x=sf, features=ZonesCharacter", {
   expect_equal(names(x$data$rij_matrix), c("z1", "z2"))
   expect_true(all(x$data$rij_matrix[[1]] == rij[[1]]))
   expect_true(all(x$data$rij_matrix[[2]] == rij[[2]]))
-  # test that calling targets before they have been inititalized throws error
+  # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
 
@@ -1070,7 +1070,7 @@ test_that("get parameter methods", {
                tibble::tibble(pu = 1, zone = "layer", status = 1))
   expect_equal(x$get_portfolio_parameter(as.Id(id4)), 100)
   expect_equal(x$get_penalty_parameter(as.Id(id5)), 200)
-  skip_if_not(any_solvers_installed())
+  skip_if_no_solvers_installed()
   id2 <- x$solver$parameters$find("gap")
   expect_equal(x$get_solver_parameter(as.Id(id2)), 0.1)
 })
@@ -1105,53 +1105,9 @@ test_that("set parameter methods", {
                tibble::tibble(pu = 2, zone = "layer", status = 1))
   expect_equal(x$get_portfolio_parameter(as.Id(id4)), 300)
   expect_equal(x$get_penalty_parameter(as.Id(id5)), 500)
-  skip_if_not(any_solvers_installed())
+  skip_if_no_solvers_installed()
   id2 <- x$solver$parameters$find("gap")
   expect_equal(x$get_solver_parameter(as.Id(id2)), 0.1)
   x$set_solver_parameter(as.Id(id2), 0.2)
   expect_equal(x$get_solver_parameter(as.Id(id2)), 0.2)
 })
-
-test_that("render parameter methods", {
-  data(sim_pu_raster, sim_features)
-  x <- problem(sim_pu_raster, sim_features) %>%
-       add_max_features_objective(400) %>%
-       add_absolute_targets(0.1) %>%
-       add_boundary_penalties(100) %>%
-       add_binary_decisions() %>%
-       add_shuffle_portfolio(100) %>%
-       add_neighbor_constraints(1) %>%
-       add_default_solver()
-  id1 <- x$objective$parameters$find("budget")
-  id3 <- x$constraints[[x$constraints$ids()[1]]]$
-           parameters$find("number of neighbors")
-  id4 <- x$portfolio$parameters$find("number_solutions")
-  id5 <- x$penalties[[x$penalties$ids()[1]]]$parameters$find("penalty")
-  expect_is(x$render_objective_parameter(as.Id(id1)), "shiny.tag")
-  expect_is(x$render_constraint_parameter(as.Id(id3)), "shiny.tag")
-  expect_is(x$render_portfolio_parameter(as.Id(id4)), "shiny.tag")
-  expect_is(x$render_penalty_parameter(as.Id(id5)),
-            c("shiny.tag", "shiny.tag.list"))
-  skip_if_not(any_solvers_installed())
-  id2 <- x$solver$parameters$find("gap")
-  expect_is(x$render_solver_parameter(as.Id(id2)), "shiny.tag")
-})
-
-test_that("render all parameters methods", {
-  skip_if_not_installed("rhandsontable")
-  data(sim_pu_raster, sim_features)
-  x <- problem(sim_pu_raster, sim_features) %>%
-       add_min_set_objective() %>%
-       add_absolute_targets(0.1) %>%
-       add_boundary_penalties(100) %>%
-       add_binary_decisions() %>%
-       add_shuffle_portfolio(100) %>%
-       add_neighbor_constraints(1) %>%
-       add_default_solver()
-  expect_is(x$render_all_objective_parameters(), "shiny.tag")
-  expect_is(x$render_all_constraint_parameters(), "shiny.tag")
-  expect_is(x$render_all_portfolio_parameters(), "shiny.tag")
-  expect_is(x$render_all_penalty_parameters(), "shiny.tag")
-  skip_if_not(any_solvers_installed())
-  expect_is(x$render_all_solver_parameters(), "shiny.tag")
-})
